@@ -14,15 +14,14 @@ import logging
 import os
 import pprint
 import sys
-import tarfile
 import urllib.error
 import urllib.parse
 import urllib.request
-import zipfile
 
 from autobuild import autobuild_base, common, configfile
 from autobuild.autobuild_tool_source_environment import get_enriched_environment
 from autobuild.hash_algorithms import verify_hash
+from autobuild import archive_utils
 
 logger = logging.getLogger('autobuild.install')
 
@@ -202,6 +201,10 @@ def download_package(package_url: str, timeout=120, creds=None, package_name="")
             token_var = CREDENTIAL_ENVVARS[creds]
         except KeyError:
             logger.warning(f"Unrecognized creds={creds} value")
+        
+        if creds == "github":
+            # Request octet-stream if creds=github, or else we'll get a JSON response back
+            req.add_unredirected_header("Accept", "application/octet-stream")
 
         token = os.environ.get(token_var)
         if token:
@@ -404,7 +407,7 @@ def _install_binary(configured_name, platform, package, config_file, install_dir
 
 def get_metadata_from_package(package_file) -> configfile.MetadataDescription:
     try:
-        with open_archive(package_file) as archive:
+        with archive_utils.open_archive(package_file) as archive:
             f = archive.extractfile(configfile.PACKAGE_METADATA_FILE)
             return configfile.MetadataDescription(stream=f)
     except (FileNotFoundError, KeyError):
@@ -438,15 +441,6 @@ def _default_metadata_for_package(package_file: str, package = None):
     return metadata
 
 
-def open_archive(filename: str) -> tarfile.TarFile | zipfile.ZipFile:
-    if filename.endswith(".tar.zst"):
-        return common.ZstdTarFile(filename, "r")
-    elif filename.endswith(".zip"):
-        return zipfile.ZipFile(filename, "r")
-    else:
-        return tarfile.open(filename, "r")
-
-
 class ExtractPackageResults:
     files: list[str]
     conflicts: list[str]
@@ -464,7 +458,7 @@ class ExtractPackageResults:
 
 
 def extract_package(package_file: str, install_dir: str, dry_run: bool = False) -> ExtractPackageResults:
-    with open_archive(package_file) as archive:
+    with archive_utils.open_archive(package_file) as archive:
         results = ExtractPackageResults()
         for t in archive:
             if t.name == configfile.PACKAGE_METADATA_FILE:
